#[non_exhaustive]pub struct GetCheckpointRequest {
pub read_mask: Option<FieldMask>,
pub transactions_filter: Option<TransactionFilter>,
pub events_filter: Option<EventFilter>,
pub max_message_size_bytes: Option<u32>,
pub checkpoint_id: Option<CheckpointId>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_mask: Option<FieldMask>Mask specifying which fields to read.
If no mask is specified, defaults to summary.
transactions_filter: Option<TransactionFilter>if no filter is passed, all transactions are included (if mentioned in the read_mask)
events_filter: Option<EventFilter>if no filter is passed, all events are included (if mentioned in the read_mask)
max_message_size_bytes: Option<u32>Optional maximum message size the client can receive (1MB - 128MB) If not specified, server uses default chunking threshold (4MB)
checkpoint_id: Option<CheckpointId>Implementations
Sourceimpl GetCheckpointRequest
impl GetCheckpointRequest
pub const LATEST_FIELD: &'static MessageField
pub const SEQUENCE_NUMBER_FIELD: &'static MessageField
pub const DIGEST_FIELD: &'static MessageField
pub const READ_MASK_FIELD: &'static MessageField
pub const TRANSACTIONS_FILTER_FIELD: &'static MessageField
pub const EVENTS_FILTER_FIELD: &'static MessageField
pub const MAX_MESSAGE_SIZE_BYTES_FIELD: &'static MessageField
Sourceimpl GetCheckpointRequest
impl GetCheckpointRequest
pub const CHECKPOINT_ID_ONEOF: &'static str = "checkpoint_id"
Sourceimpl GetCheckpointRequest
impl GetCheckpointRequest
Sourcepub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
pub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
Sets read_mask with the provided value.
Sourcepub fn with_transactions_filter<T: Into<TransactionFilter>>(
self,
field: T,
) -> Self
pub fn with_transactions_filter<T: Into<TransactionFilter>>( self, field: T, ) -> Self
Sets transactions_filter with the provided value.
Sourcepub fn with_events_filter<T: Into<EventFilter>>(self, field: T) -> Self
pub fn with_events_filter<T: Into<EventFilter>>(self, field: T) -> Self
Sets events_filter with the provided value.
Sourcepub fn with_max_message_size_bytes(self, field: u32) -> Self
pub fn with_max_message_size_bytes(self, field: u32) -> Self
Sets max_message_size_bytes with the provided value.
Sourcepub fn with_latest(self, field: bool) -> Self
pub fn with_latest(self, field: bool) -> Self
Sets latest with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_sequence_number(self, field: u64) -> Self
pub fn with_sequence_number(self, field: u64) -> Self
Sets sequence_number with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_digest<T: Into<Digest>>(self, field: T) -> Self
pub fn with_digest<T: Into<Digest>>(self, field: T) -> Self
Sets digest with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourceimpl GetCheckpointRequest
impl GetCheckpointRequest
Sourcepub fn max_message_size_bytes(&self) -> u32
pub fn max_message_size_bytes(&self) -> u32
Returns the value of max_message_size_bytes, or the default value if max_message_size_bytes is unset.