GetEpochRequest

Struct GetEpochRequest 

#[non_exhaustive]
pub struct GetEpochRequest { pub epoch: Option<u64>, pub read_mask: Option<FieldMask>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
epoch: Option<u64>

The requested epoch. If no epoch is provided the current epoch will be returned.

read_mask: Option<FieldMask>

Mask specifying which fields to read. If no mask is specified, defaults to epoch.

Implementations

Source

impl GetEpochRequest

pub const EPOCH_FIELD: &'static MessageField

pub const READ_MASK_FIELD: &'static MessageField

Source

impl GetEpochRequest

Source

impl GetEpochRequest

pub fn with_epoch(self, field: u64) -> Self

Sets epoch with the provided value.

pub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self

Sets read_mask with the provided value.

Source

impl GetEpochRequest

pub fn epoch(&self) -> u64

Returns the value of epoch, or the default value if epoch is unset.