#[non_exhaustive]pub struct GetTransactionsRequest {
pub requests: Option<TransactionRequests>,
pub read_mask: Option<FieldMask>,
pub max_message_size_bytes: Option<u32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.requests: Option<TransactionRequests>read_mask: Option<FieldMask>Mask specifying which fields to read.
If no mask is specified, defaults to transaction.digest.
max_message_size_bytes: Option<u32>Optional maximum message size the client can receive (1MB - 128MB) If not specified, server uses default chunking threshold (4MB)
Implementations
Sourceimpl GetTransactionsRequest
impl GetTransactionsRequest
pub const REQUESTS_FIELD: &'static MessageField
pub const READ_MASK_FIELD: &'static MessageField
pub const MAX_MESSAGE_SIZE_BYTES_FIELD: &'static MessageField
Sourceimpl GetTransactionsRequest
impl GetTransactionsRequest
Sourcepub fn with_requests<T: Into<TransactionRequests>>(self, field: T) -> Self
pub fn with_requests<T: Into<TransactionRequests>>(self, field: T) -> Self
Sets requests with the provided value.
Sourcepub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
pub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
Sets read_mask with the provided value.
Sourcepub fn with_max_message_size_bytes(self, field: u32) -> Self
pub fn with_max_message_size_bytes(self, field: u32) -> Self
Sets max_message_size_bytes with the provided value.
Sourceimpl GetTransactionsRequest
impl GetTransactionsRequest
Sourcepub fn max_message_size_bytes(&self) -> u32
pub fn max_message_size_bytes(&self) -> u32
Returns the value of max_message_size_bytes, or the default value if max_message_size_bytes is unset.