#[non_exhaustive]pub struct ObjectResult {
pub result: Option<Result>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.result: Option<Result>Implementations
Sourceimpl ObjectResult
impl ObjectResult
pub const OBJECT_FIELD: &'static MessageField
pub const ERROR_FIELD: &'static MessageField
Sourceimpl ObjectResult
impl ObjectResult
pub const RESULT_ONEOF: &'static str = "result"
Sourceimpl ObjectResult
impl ObjectResult
pub fn path_builder() -> ObjectResultFieldPathBuilder
Sourceimpl ObjectResult
impl ObjectResult
Sourcepub fn with_object<T: Into<Object>>(self, field: T) -> Self
pub fn with_object<T: Into<Object>>(self, field: T) -> Self
Sets object with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_error<T: Into<Status>>(self, field: T) -> Self
pub fn with_error<T: Into<Status>>(self, field: T) -> Self
Sets error with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourceimpl ObjectResult
impl ObjectResult
Sourcepub fn object(&self) -> Result<Option<&Object>, TryFromProtoError>
pub fn object(&self) -> Result<Option<&Object>, TryFromProtoError>
Get the object if this result is an object.
Sourcepub fn error_code(&self) -> Option<i32>
pub fn error_code(&self) -> Option<i32>
Get the error code if this result is an error.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
Get the error message if this result is an error.