#[non_exhaustive]pub struct StreamCheckpointsRequest {
pub start_sequence_number: Option<u64>,
pub end_sequence_number: Option<u64>,
pub read_mask: Option<FieldMask>,
pub transactions_filter: Option<TransactionFilter>,
pub events_filter: Option<EventFilter>,
pub filter_checkpoints: Option<bool>,
pub progress_interval_ms: Option<u32>,
pub max_message_size_bytes: Option<u32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_sequence_number: Option<u64>if no start sequence number is provided, streaming starts from the latest checkpoint
end_sequence_number: Option<u64>if no end sequence number is provided, streaming continues forever
read_mask: Option<FieldMask>Mask specifying which fields to read.
If no mask is specified, defaults to summary.
transactions_filter: Option<TransactionFilter>if no filter is passed, all transactions are included (if mentioned in the read_mask)
events_filter: Option<EventFilter>if no filter is passed, all events are included (if mentioned in the read_mask)
filter_checkpoints: Option<bool>When true, checkpoints with no matching transactions or events are skipped entirely. At least one of transactions_filter or events_filter must be set. A Progress message is sent periodically to indicate liveness and scan position.
progress_interval_ms: Option<u32>Progress message interval in milliseconds when filter_checkpoints is enabled. Defaults to 2000ms. Minimum value is 500ms; lower values are clamped.
max_message_size_bytes: Option<u32>Optional maximum message size the client can receive (1MB - 128MB) If not specified, server uses default chunking threshold (4MB)
Implementations
Sourceimpl StreamCheckpointsRequest
impl StreamCheckpointsRequest
pub const START_SEQUENCE_NUMBER_FIELD: &'static MessageField
pub const END_SEQUENCE_NUMBER_FIELD: &'static MessageField
pub const READ_MASK_FIELD: &'static MessageField
pub const TRANSACTIONS_FILTER_FIELD: &'static MessageField
pub const EVENTS_FILTER_FIELD: &'static MessageField
pub const FILTER_CHECKPOINTS_FIELD: &'static MessageField
pub const PROGRESS_INTERVAL_MS_FIELD: &'static MessageField
pub const MAX_MESSAGE_SIZE_BYTES_FIELD: &'static MessageField
Sourceimpl StreamCheckpointsRequest
impl StreamCheckpointsRequest
Sourcepub fn with_start_sequence_number(self, field: u64) -> Self
pub fn with_start_sequence_number(self, field: u64) -> Self
Sets start_sequence_number with the provided value.
Sourcepub fn with_end_sequence_number(self, field: u64) -> Self
pub fn with_end_sequence_number(self, field: u64) -> Self
Sets end_sequence_number with the provided value.
Sourcepub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
pub fn with_read_mask<T: Into<FieldMask>>(self, field: T) -> Self
Sets read_mask with the provided value.
Sourcepub fn with_transactions_filter<T: Into<TransactionFilter>>(
self,
field: T,
) -> Self
pub fn with_transactions_filter<T: Into<TransactionFilter>>( self, field: T, ) -> Self
Sets transactions_filter with the provided value.
Sourcepub fn with_events_filter<T: Into<EventFilter>>(self, field: T) -> Self
pub fn with_events_filter<T: Into<EventFilter>>(self, field: T) -> Self
Sets events_filter with the provided value.
Sourcepub fn with_filter_checkpoints(self, field: bool) -> Self
pub fn with_filter_checkpoints(self, field: bool) -> Self
Sets filter_checkpoints with the provided value.
Sourcepub fn with_progress_interval_ms(self, field: u32) -> Self
pub fn with_progress_interval_ms(self, field: u32) -> Self
Sets progress_interval_ms with the provided value.
Sourcepub fn with_max_message_size_bytes(self, field: u32) -> Self
pub fn with_max_message_size_bytes(self, field: u32) -> Self
Sets max_message_size_bytes with the provided value.
Sourceimpl StreamCheckpointsRequest
impl StreamCheckpointsRequest
Sourcepub fn start_sequence_number(&self) -> u64
pub fn start_sequence_number(&self) -> u64
Returns the value of start_sequence_number, or the default value if start_sequence_number is unset.
Sourcepub fn end_sequence_number(&self) -> u64
pub fn end_sequence_number(&self) -> u64
Returns the value of end_sequence_number, or the default value if end_sequence_number is unset.
Sourcepub fn filter_checkpoints(&self) -> bool
pub fn filter_checkpoints(&self) -> bool
Returns the value of filter_checkpoints, or the default value if filter_checkpoints is unset.
Sourcepub fn progress_interval_ms(&self) -> u32
pub fn progress_interval_ms(&self) -> u32
Returns the value of progress_interval_ms, or the default value if progress_interval_ms is unset.
Sourcepub fn max_message_size_bytes(&self) -> u32
pub fn max_message_size_bytes(&self) -> u32
Returns the value of max_message_size_bytes, or the default value if max_message_size_bytes is unset.