#[non_exhaustive]pub struct GetServiceInfoResponse {
pub chain_id: Option<Digest>,
pub chain: Option<String>,
pub epoch: Option<u64>,
pub executed_checkpoint_height: Option<u64>,
pub executed_checkpoint_timestamp: Option<Timestamp>,
pub lowest_available_checkpoint: Option<u64>,
pub lowest_available_checkpoint_objects: Option<u64>,
pub server: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.chain_id: Option<Digest>The chain identifier of the chain that this node is on.
The chain identifier is the digest of the genesis checkpoint, the checkpoint with sequence number 0.
chain: Option<String>Human-readable name of the chain that this node is on.
This is intended to be a human-readable name like mainnet, testnet, and so on.
epoch: Option<u64>Current epoch of the node based on its highest executed checkpoint.
executed_checkpoint_height: Option<u64>Checkpoint height of the most recently executed checkpoint.
executed_checkpoint_timestamp: Option<Timestamp>Unix timestamp of the most recently executed checkpoint.
lowest_available_checkpoint: Option<u64>The lowest checkpoint for which checkpoints and transaction data are available.
lowest_available_checkpoint_objects: Option<u64>The lowest checkpoint for which object data is available.
server: Option<String>Software version of the service. Similar to the server http header.
Implementations
Sourceimpl GetServiceInfoResponse
impl GetServiceInfoResponse
pub const CHAIN_ID_FIELD: &'static MessageField
pub const CHAIN_FIELD: &'static MessageField
pub const EPOCH_FIELD: &'static MessageField
pub const EXECUTED_CHECKPOINT_HEIGHT_FIELD: &'static MessageField
pub const EXECUTED_CHECKPOINT_TIMESTAMP_FIELD: &'static MessageField
pub const LOWEST_AVAILABLE_CHECKPOINT_FIELD: &'static MessageField
pub const LOWEST_AVAILABLE_CHECKPOINT_OBJECTS_FIELD: &'static MessageField
pub const SERVER_FIELD: &'static MessageField
Sourceimpl GetServiceInfoResponse
impl GetServiceInfoResponse
Sourcepub fn with_chain_id<T: Into<Digest>>(self, field: T) -> Self
pub fn with_chain_id<T: Into<Digest>>(self, field: T) -> Self
Sets chain_id with the provided value.
Sourcepub fn with_chain<T: Into<String>>(self, field: T) -> Self
pub fn with_chain<T: Into<String>>(self, field: T) -> Self
Sets chain with the provided value.
Sourcepub fn with_epoch(self, field: u64) -> Self
pub fn with_epoch(self, field: u64) -> Self
Sets epoch with the provided value.
Sourcepub fn with_executed_checkpoint_height(self, field: u64) -> Self
pub fn with_executed_checkpoint_height(self, field: u64) -> Self
Sets executed_checkpoint_height with the provided value.
Sourcepub fn with_executed_checkpoint_timestamp<T: Into<Timestamp>>(
self,
field: T,
) -> Self
pub fn with_executed_checkpoint_timestamp<T: Into<Timestamp>>( self, field: T, ) -> Self
Sets executed_checkpoint_timestamp with the provided value.
Sourcepub fn with_lowest_available_checkpoint(self, field: u64) -> Self
pub fn with_lowest_available_checkpoint(self, field: u64) -> Self
Sets lowest_available_checkpoint with the provided value.
Sourcepub fn with_lowest_available_checkpoint_objects(self, field: u64) -> Self
pub fn with_lowest_available_checkpoint_objects(self, field: u64) -> Self
Sets lowest_available_checkpoint_objects with the provided value.
Sourcepub fn with_server<T: Into<String>>(self, field: T) -> Self
pub fn with_server<T: Into<String>>(self, field: T) -> Self
Sets server with the provided value.
Sourceimpl GetServiceInfoResponse
impl GetServiceInfoResponse
Sourcepub fn chain(&self) -> &str
pub fn chain(&self) -> &str
Returns the value of chain, or the default value if chain is unset.
Sourcepub fn executed_checkpoint_height(&self) -> u64
pub fn executed_checkpoint_height(&self) -> u64
Returns the value of executed_checkpoint_height, or the default value if executed_checkpoint_height is unset.
Sourcepub fn lowest_available_checkpoint(&self) -> u64
pub fn lowest_available_checkpoint(&self) -> u64
Returns the value of lowest_available_checkpoint, or the default value if lowest_available_checkpoint is unset.
Sourcepub fn lowest_available_checkpoint_objects(&self) -> u64
pub fn lowest_available_checkpoint_objects(&self) -> u64
Returns the value of lowest_available_checkpoint_objects, or the default value if lowest_available_checkpoint_objects is unset.
Sourceimpl GetServiceInfoResponse
impl GetServiceInfoResponse
Sourcepub fn chain_identifier(&self) -> Result<Digest, TryFromProtoError>
pub fn chain_identifier(&self) -> Result<Digest, TryFromProtoError>
Get the chain identifier (digest of genesis checkpoint).
Sourcepub fn chain_name(&self) -> Result<&str, TryFromProtoError>
pub fn chain_name(&self) -> Result<&str, TryFromProtoError>
Get the human-readable chain name (e.g., “mainnet”, “testnet”).
Sourcepub fn epoch_id(&self) -> Result<EpochId, TryFromProtoError>
pub fn epoch_id(&self) -> Result<EpochId, TryFromProtoError>
Get the current epoch ID.
Sourcepub fn checkpoint_executed(
&self,
) -> Result<CheckpointSequenceNumber, TryFromProtoError>
pub fn checkpoint_executed( &self, ) -> Result<CheckpointSequenceNumber, TryFromProtoError>
Get the checkpoint height of the most recently executed checkpoint.
Sourcepub fn checkpoint_executed_timestamp_ms(
&self,
) -> Result<CheckpointTimestamp, TryFromProtoError>
pub fn checkpoint_executed_timestamp_ms( &self, ) -> Result<CheckpointTimestamp, TryFromProtoError>
Get the Unix timestamp of the most recently executed checkpoint in milliseconds.
Sourcepub fn checkpoint_lowest(
&self,
) -> Result<CheckpointSequenceNumber, TryFromProtoError>
pub fn checkpoint_lowest( &self, ) -> Result<CheckpointSequenceNumber, TryFromProtoError>
Get the lowest checkpoint for which checkpoints and transaction data are available.
Sourcepub fn checkpoint_objects_lowest(
&self,
) -> Result<CheckpointSequenceNumber, TryFromProtoError>
pub fn checkpoint_objects_lowest( &self, ) -> Result<CheckpointSequenceNumber, TryFromProtoError>
Get the lowest checkpoint for which object data is available.
Sourcepub fn server_version(&self) -> Result<&str, TryFromProtoError>
pub fn server_version(&self) -> Result<&str, TryFromProtoError>
Get the software version of the service.